@@ -10,13 +10,13 @@ class Metaclass(ABCMeta):
         protocol = function.protocol
         if callable(function.protocol):
             protocol = function.protocol(*args, **kwargs)
-        if protocol == 'class':
+        if protocol == self.CLASS:
             function.__init__(*args, **kwargs)
             return function.__call__()
-        elif protocol == 'function':
+        elif protocol == self.FUNCTION:
             function.__init__()
             return function.__call__(*args, **kwargs)
-        elif protocol == 'decorator':
+        elif protocol == self.DECORATOR:
             function.__init__(*args, **kwargs)
             return function
         else:
@@ -32,7 +32,7 @@ class Metaclass(ABCMeta):
 
 
 class Function(metaclass=Metaclass):
-    """Abstract class based function representation.
+    """Abstract class-based function representation.
 
     Designed to implement functions/decorators as classes
     to work with state and inheritance. In this model function will
@@ -51,11 +51,11 @@ class Function(metaclass=Metaclass):
     --------
     Invocation protocols:
 
-    - class
+    - Function.CLASS (default)
 
         >>> from sugarbowl import Function
         >>> class echo(Function):
-        ...   protocol = 'class'
+        ...   protocol = Function.CLASS
         ...   def __init__(self, value):
         ...     self.value = value
         ...   def __call__(self):
@@ -63,21 +63,21 @@ class Function(metaclass=Metaclass):
         >>> echo('Hello World')
         'Hello World!'
 
-    - function
+    - Function.FUNCTION
 
         >>> from sugarbowl import Function
         >>> class echo(Function):
-        ...   protocol = 'function'
+        ...   protocol = Function.FUNCTION
         ...   def __call__(self, value):
         ...     return value
         >>> echo('Hello World!')
         'Hello World!'
 
-    - decorator
+    - Function.DECORATOR
 
         >>> from sugarbowl import Function
         >>> class echo(Function):
-        ...   protocol = 'decorator'
+        ...   protocol = Function.DECORATOR
         ...   def __init__(self, value):
         ...     self.value = value
         ...   def __call__(self, processor):
@@ -88,7 +88,11 @@ class Function(metaclass=Metaclass):
 
     # Public
 
-    protocol = 'class'
+    CLASS = 'class'
+    FUNCTION = 'function'
+    DECORATOR = 'decorator'
+
+    protocol = CLASS
     """Invocation protocol.
     """
 
